@@ -99,8 +99,8 @@ typedef enum ORIENTATION_PREFERENCE {
     ORIENTATION_PREFERENCE_PORTRAIT_FLIPPED = 0x8
 } ORIENTATION_PREFERENCE;
 typedef BOOL WINAPI (*pSetDisplayAutoRotationPreferences_t)(
-    ORIENTATION_PREFERENCE orientation
-);
+        ORIENTATION_PREFERENCE orientation
+        );
 void resetRotation()
 {
     QLibrary user32Lib("user32");
@@ -189,8 +189,8 @@ extern "C" int main(int argc, char **argv)
     }
 
 
-    QString language;
     QString root;
+    QString language;
     {
         // Create a temporary application to get the root
         QCoreApplication app(argc, argv);
@@ -219,29 +219,41 @@ extern "C" int main(int argc, char **argv)
 
     // Now that the paths are set, set the language. First check the override from the language
     // selection dialog.
-    {
-        qDebug() << "Override language:" << language;
 
-        if (!language.isEmpty()) {
-            KLocalizedString::setLanguages(language.split(":"));
-            // And override Qt's locale, too
-            qputenv("LANG", language.split(":").first().toUtf8());
-            QLocale locale(language.split(":").first());
-            QLocale::setDefault(locale);
-        }
-#ifndef Q_OS_LINUX
-        else {
-            // And if there isn't one, check the one set by the system.
-            QLocale locale = QLocale::system();
-            if (locale.name() != QStringLiteral("en")) {
-                qDebug() << "Setting Krita's language to:" << locale;
-                qputenv("LANG", locale.name().toLatin1());
-                KLocalizedString::setLanguages(QStringList() << locale.name());
-            }
-        }
-#endif
+    qDebug() << "Override language:" << language;
+
+    if (!language.isEmpty()) {
+        KLocalizedString::setLanguages(language.split(":"));
+        // And override Qt's locale, too
+        qputenv("LANG", language.split(":").first().toLocal8Bit());
+        QLocale locale(language.split(":").first());
+        QLocale::setDefault(locale);
     }
-
+#ifndef Q_OS_LINUX
+    else {
+        // And if there isn't one, check the one set by the system.
+        QLocale locale = QLocale::system();
+        if (locale.name() != QStringLiteral("en")) {
+            QStringList uiLanguages = locale.uiLanguages();
+            for (QString &uiLanguage : uiLanguages) {
+                uiLanguage.replace(QChar('-'), QChar('_'));
+            }
+            for (int i = 0; i < uiLanguages.size(); i++) {
+                QString uiLanguage = uiLanguages[i];
+                // Strip the country code
+                int idx = uiLanguage.indexOf(QChar('_'));
+                if (idx != -1) {
+                    uiLanguage = uiLanguage.left(idx);
+                    uiLanguages.insert(i + 1, uiLanguage);
+                    i++;
+                }
+            }
+            qDebug() << "Setting Krita's language to:" << uiLanguages;
+            qputenv("LANG", uiLanguages.first().toLocal8Bit());
+            KLocalizedString::setLanguages(uiLanguages);
+        }
+    }
+#endif
     // first create the application so we can create a pixmap
     KisApplication app(key, argc, argv);
     KLocalizedString::setApplicationDomain("krita");
@@ -284,7 +296,7 @@ extern "C" int main(int argc, char **argv)
     if (singleApplication && app.isRunning()) {
         // only pass arguments to main instance if they are not for batch processing
         // any batch processing would be done in this separate instance
-        const bool batchRun = (args.print() || args.exportAs() || args.exportAsPdf());
+        const bool batchRun = args.exportAs();
 
         if (!batchRun) {
             QByteArray ba = args.serialize();
