@@ -231,3 +231,88 @@ void KisGaussianKernel::applyLoG(KisPaintDeviceSP device,
 
     painter.applyMatrix(kernel, device, srcTopLeft, srcTopLeft, rect.size(), BORDER_REPEAT);
 }
+
+Eigen::Matrix<qreal, Eigen::Dynamic, Eigen::Dynamic> KisGaussianKernel::createDilateMatrix(qreal radius)
+{
+    int kernelSize = 2 * std::ceil(radius) + 1;
+    Eigen::Matrix<qreal, Eigen::Dynamic, Eigen::Dynamic> matrix(kernelSize, kernelSize);
+
+
+    struct UnionFade {
+        quint8 value(qreal) const {
+            return 255;
+        }
+    };
+
+    const qreal fadeStart = radius - 1.0;
+
+    /**
+     * The kernel size should always be odd, then the position of the
+     * central pixel can be easily calculated
+     */
+    KIS_ASSERT_RECOVER_NOOP(kernelSize & 0x1);
+    const int center = kernelSize / 2;
+
+    for (int y = 0; y < kernelSize; y++) {
+        const qreal yDistance = center - y;
+        for (int x = 0; x < kernelSize; x++) {
+            const qreal xDistance = center - x;
+
+            const qreal distance = std::sqrt(pow2(xDistance) + pow2(yDistance));
+
+            qreal value = 1.0;
+
+            if (distance >= radius) {
+                value = 0.0;
+            } else if (distance > fadeStart) {
+                value = radius - distance;
+            }
+
+            matrix(x, y) = value;
+        }
+    }
+
+    return matrix;
+}
+
+void KisGaussianKernel::applyDilate(KisPaintDeviceSP device, const QRect &rect, qreal radius, const QBitArray &channelFlags, KoUpdater *progressUpdater)
+{
+    QPoint srcTopLeft = rect.topLeft();
+
+    KisConvolutionPainter painter(device);
+    painter.setChannelFlags(channelFlags);
+    painter.setProgress(progressUpdater);
+
+    Eigen::Matrix<qreal, Eigen::Dynamic, Eigen::Dynamic> matrix = createDilateMatrix(radius);
+    KisConvolutionKernelSP kernel =
+        KisConvolutionKernel::fromMatrix(matrix,
+                                         0,
+                                         0);
+
+    painter.applyMatrix(kernel, device, srcTopLeft, srcTopLeft, rect.size(), BORDER_REPEAT);
+}
+
+#include "kis_sequential_iterator.h"
+
+void KisGaussianKernel::applyErodeU8(KisPaintDeviceSP device, const QRect &rect, qreal radius, const QBitArray &channelFlags, KoUpdater *progressUpdater)
+{
+    KIS_SAFE_ASSERT_RECOVER_RETURN(device->colorSpace()->pixelSize() == 1);
+
+    {
+        KisSequentialIterator dstIt(device, rect);
+        while (dstIt.nextPixel()) {
+            quint8 *dstPtr = dstIt.rawData();
+            *dstPtr = 255 - *dstPtr;
+        }
+    }
+
+    applyDilate(device, rect, radius, channelFlags, progressUpdater);
+
+    {
+        KisSequentialIterator dstIt(device, rect);
+        while (dstIt.nextPixel()) {
+            quint8 *dstPtr = dstIt.rawData();
+            *dstPtr = 255 - *dstPtr;
+        }
+    }
+}
