@@ -331,8 +331,10 @@ Document* Krita::createDocument(int width, int height, const QString &name, cons
 Document* Krita::openDocument(const QString &filename)
 {
     KisDocument *document = KisPart::instance()->createDocument();
+    document->setFileBatchMode(this->batchmode());
     KisPart::instance()->addDocument(document);
     document->openUrl(QUrl::fromLocalFile(filename), KisDocument::DontAddToRecent);
+    document->setFileBatchMode(false);
     return new Document(document);
 }
 
