@@ -42,9 +42,7 @@ struct Q_DECL_HIDDEN KisApplicationArguments::Private
     int dpiX {72};
     int dpiY {72};
     bool doTemplate {false};
-    bool print {false};
     bool exportAs {false};
-    bool exportAsPdf {false};
     QString exportFileName;
     QString workspace;
     bool canvasOnly {false};
@@ -75,7 +73,6 @@ KisApplicationArguments::KisApplicationArguments(const QApplication &app)
     QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
-    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("print"), i18n("Only print and exit")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("template"), i18n("Open a new document with a template")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("new-image"), i18n("Create a new image on startup.\n"
                                                                                           "Possible colorspace values are:\n"
@@ -96,9 +93,8 @@ KisApplicationArguments::KisApplicationArguments(const QApplication &app)
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("nosplash"), i18n("Do not show the splash screen")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("fullscreen"), i18n("Start Krita in full-screen mode")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("dpi"), i18n("Override display DPI"), QLatin1String("dpiX,dpiY")));
-    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("export-pdf"), i18n("Only export to PDF and exit")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("export"), i18n("Export to the given filename and exit")));
-    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("export-filename"), i18n("Filename for export/export-pdf"), QLatin1String("filename")));
+    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("export-filename"), i18n("Filename for export"), QLatin1String("filename")));
     parser.addPositionalArgument(QLatin1String("[file(s)]"), i18n("File(s) or URL(s) to open"));
     parser.process(app);
 
@@ -137,9 +133,7 @@ KisApplicationArguments::KisApplicationArguments(const QApplication &app)
     d->exportFileName = parser.value("export-filename");
     d->workspace = parser.value("workspace");
     d->doTemplate = parser.isSet("template");
-    d->print = parser.isSet("print");
     d->exportAs = parser.isSet("export");
-    d->exportAsPdf = parser.isSet("export-pdf");
     d->canvasOnly = parser.isSet("canvasonly");
     d->noSplash = parser.isSet("nosplash");
     d->fullScreen = parser.isSet("fullscreen");
@@ -157,9 +151,7 @@ KisApplicationArguments::KisApplicationArguments(const KisApplicationArguments &
     d->dpiX = rhs.dpiX();
     d->dpiY = rhs.dpiY();
     d->doTemplate = rhs.doTemplate();
-    d->print = rhs.print();
     d->exportAs = rhs.exportAs();
-    d->exportAsPdf = rhs.exportAsPdf();
     d->exportFileName = rhs.exportFileName();
     d->canvasOnly = rhs.canvasOnly();
     d->workspace = rhs.workspace();
@@ -173,9 +165,7 @@ void KisApplicationArguments::operator=(const KisApplicationArguments &rhs)
     d->dpiX = rhs.dpiX();
     d->dpiY = rhs.dpiY();
     d->doTemplate = rhs.doTemplate();
-    d->print = rhs.print();
     d->exportAs = rhs.exportAs();
-    d->exportAsPdf = rhs.exportAsPdf();
     d->exportFileName = rhs.exportFileName();
     d->canvasOnly = rhs.canvasOnly();
     d->workspace = rhs.workspace();
@@ -197,9 +187,7 @@ QByteArray KisApplicationArguments::serialize()
     ds << d->dpiX;
     ds << d->dpiY;
     ds << d->doTemplate;
-    ds << d->print;
     ds << d->exportAs;
-    ds << d->exportAsPdf;
     ds << d->exportFileName;
     ds << d->workspace;
     ds << d->canvasOnly;
@@ -237,9 +225,7 @@ KisApplicationArguments KisApplicationArguments::deserialize(QByteArray &seriali
     ds >> args.d->dpiX;
     ds >> args.d->dpiY;
     ds >> args.d->doTemplate;
-    ds >> args.d->print;
     ds >> args.d->exportAs;
-    ds >> args.d->exportAsPdf;
     ds >> args.d->exportFileName;
     ds >> args.d->workspace;
     ds >> args.d->canvasOnly;
@@ -277,21 +263,11 @@ bool KisApplicationArguments::doTemplate() const
     return d->doTemplate;
 }
 
-bool KisApplicationArguments::print() const
-{
-    return d->print;
-}
-
 bool KisApplicationArguments::exportAs() const
 {
     return d->exportAs;
 }
 
-bool KisApplicationArguments::exportAsPdf() const
-{
-    return d->exportAsPdf;
-}
-
 QString KisApplicationArguments::exportFileName() const
 {
     return d->exportFileName;
