@@ -43,7 +43,10 @@ KisDlgFileLayer::KisDlgFileLayer(const QString &basePath, const QString & name,
     setDefaultButton(Ok);
     QWidget * page = new QWidget(this);
     dlgWidget.setupUi(page);
-    dlgWidget.wdgUrlRequester->setMimeTypeFilters(KisImportExportManager::mimeFilter(KisImportExportManager::Import));
+    QStringList mimes = KisImportExportManager::mimeFilter(KisImportExportManager::Import);
+    // Nesting .kra files is not supported, so do not offer that option. See https://bugs.kde.org/show_bug.cgi?id=386515
+    mimes.removeAll("application/x-krita");
+    dlgWidget.wdgUrlRequester->setMimeTypeFilters(mimes);
     setMainWidget(page);
 
     //dlgWidget.wdgUrlRequester->setBasePath(m_basePath);
