@@ -44,7 +44,7 @@
  *        we store it separately.
  *
  *     2) This objects allows merging (compressing) multiple moves of
- *        a layer into a signle action. This behavior is implemented
+ *        a layer into a single action. This behavior is implemented
  *        in tryMerge() method.
  */
 struct MoveNodeStruct {
@@ -233,7 +233,7 @@ public:
     {
     }
 
-    void end() {
+    void end() override {
         if (isFinalizing() && isFirstRedo()) {
             /**
              * When doing the first redo() some of the updates might
@@ -244,7 +244,7 @@ public:
         } else {
             /**
              * When being executed by real undo/redo operations, we
-             * should emit all the update signals. Noone else will do
+             * should emit all the update signals. No one else will do
              * that for us (juggler, which did it in the previous
              * case, might have already died).
              */
@@ -270,7 +270,21 @@ public:
     {
     }
 
-    void end() {
+    void init() override {
+        QList<KisSelectionMaskSP> *newActiveMasks;
+
+        if (isFinalizing()) {
+            newActiveMasks = &m_activeAfter;
+        } else {
+            newActiveMasks = &m_activeBefore;
+        }
+
+        Q_FOREACH (KisSelectionMaskSP mask, *newActiveMasks) {
+            mask->setActive(false);
+        }
+    }
+
+    void end() override {
         QList<KisSelectionMaskSP> *newActiveMasks;
 
         if (isFinalizing()) {
@@ -347,7 +361,7 @@ struct LowerRaiseLayer : public KisCommandUtils::AggregateCommand {
             AllMasks;
     }
 
-    void populateChildCommands() {
+    void populateChildCommands() override {
         KisNodeList sortedNodes = sortAndFilterNodes(m_nodes, m_image);
         KisNodeSP headNode = m_lower ? sortedNodes.first() : sortedNodes.last();
         const NodesType nodesType = getNodesType(sortedNodes);
@@ -472,7 +486,7 @@ struct DuplicateLayers : public KisCommandUtils::AggregateCommand {
           m_activeNode(activeNode),
           m_mode(mode) {}
 
-    void populateChildCommands() {
+    void populateChildCommands() override {
         KisNodeList filteredNodes = sortAndFilterNodes(m_nodes, m_image);
 
         if (filteredNodes.isEmpty()) return;
@@ -488,6 +502,14 @@ struct DuplicateLayers : public KisCommandUtils::AggregateCommand {
 
         const int indexOfActiveNode = filteredNodes.indexOf(m_activeNode);
         QList<KisSelectionMaskSP> activeMasks = findActiveSelectionMasks(filteredNodes);
+
+        // we will deactivate the masks before processing, so we should
+        // save their list in a convenient form
+        QSet<KisNodeSP> activeMaskNodes;
+        Q_FOREACH (KisSelectionMaskSP mask, activeMasks) {
+            activeMaskNodes.insert(mask);
+        }
+
         const bool haveActiveMasks = !activeMasks.isEmpty();
 
         if (!newParent) return;
@@ -497,6 +519,15 @@ struct DuplicateLayers : public KisCommandUtils::AggregateCommand {
                                                                m_image, false));
 
         if (haveActiveMasks) {
+            /**
+             * We should first disable the currently active masks, after the operation
+             * completed their cloned counterparts will be activated instead.
+             *
+             * HINT: we should deactivate the masks before cloning, because otherwise
+             *       KisGroupLayer::allowAsChild() will not let the second mask to be
+             *       added to the list of child nodes. See bug 382315.
+             */
+
             addCommand(new ActivateSelectionMasksCommand(activeMasks,
                                                          QList<KisSelectionMaskSP>(),
                                                          false));
@@ -517,7 +548,7 @@ struct DuplicateLayers : public KisCommandUtils::AggregateCommand {
                 }
 
                 newNodes << newNode;
-                if (haveActiveMasks && toActiveSelectionMask(node)) {
+                if (haveActiveMasks && activeMaskNodes.contains(node)) {
                     KisSelectionMaskSP mask = dynamic_cast<KisSelectionMask*>(newNode.data());
                     newActiveMasks << mask;
                 }
@@ -534,7 +565,7 @@ struct DuplicateLayers : public KisCommandUtils::AggregateCommand {
                 KisNodeSP newNode = node;
 
                 newNodes << newNode;
-                if (haveActiveMasks && toActiveSelectionMask(node)) {
+                if (haveActiveMasks && activeMaskNodes.contains(node)) {
                     KisSelectionMaskSP mask = dynamic_cast<KisSelectionMask*>(newNode.data());
                     newActiveMasks << mask;
                 }
@@ -552,6 +583,10 @@ struct DuplicateLayers : public KisCommandUtils::AggregateCommand {
 
 
         if (haveActiveMasks) {
+            /**
+             * Activate the cloned counterparts of the masks after the operation
+             * is complete.
+             */
             addCommand(new ActivateSelectionMasksCommand(QList<KisSelectionMaskSP>(),
                                                          newActiveMasks,
                                                          true));
@@ -600,7 +635,7 @@ struct RemoveLayers : private KisLayerUtils::RemoveNodeHelper, public KisCommand
           m_nodes(nodes),
           m_activeNode(activeNode){}
 
-    void populateChildCommands() {
+    void populateChildCommands() override {
         KisNodeList filteredNodes = m_nodes;
         KisLayerUtils::filterMergableNodes(filteredNodes, true);
 
@@ -622,7 +657,7 @@ struct RemoveLayers : private KisLayerUtils::RemoveNodeHelper, public KisCommand
                                                                m_image, true));
     }
 protected:
-    virtual void addCommandImpl(KUndo2Command *cmd) {
+    void addCommandImpl(KUndo2Command *cmd) override {
         addCommand(cmd);
     }
 
