@@ -251,16 +251,18 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
             slSize    = m_sliderChooser[i]->addWidget<KisDoubleSliderSpinBox>("size", i18n("Size:"));
         }
 
-        slOpacity->setRange(0.0, 1.0, 2);
-        slOpacity->setValue(1.0);
-        slOpacity->setSingleStep(0.05);
+        slOpacity->setRange(0, 100, 0);
+        slOpacity->setValue(100);
+        slOpacity->setSingleStep(5);
+        slOpacity->setSuffix("%");
         slOpacity->setMinimumWidth(qMax(sliderWidth, slOpacity->sizeHint().width()));
         slOpacity->setFixedHeight(iconsize);
         slOpacity->setBlockUpdateSignalOnDrag(true);
 
-        slFlow->setRange(0.0, 1.0, 2);
-        slFlow->setValue(1.0);
-        slFlow->setSingleStep(0.05);
+        slFlow->setRange(0, 100, 0);
+        slFlow->setValue(100);
+        slFlow->setSingleStep(5);
+        slFlow->setSuffix("%");
         slFlow->setMinimumWidth(qMax(sliderWidth, slFlow->sizeHint().width()));
         slFlow->setFixedHeight(iconsize);
         slFlow->setBlockUpdateSignalOnDrag(true);
@@ -751,7 +753,14 @@ void KisPaintopBox::setSliderValue(const QString& sliderID, qreal value)
     for (int i = 0; i < 3; ++i) {
         KisDoubleSliderSpinBox* slider = m_sliderChooser[i]->getWidget<KisDoubleSliderSpinBox>(sliderID);
         KisSignalsBlocker b(slider);
-        slider->setValue(value);
+
+        if (sliderID == "opacity" || sliderID == "flow") { // opacity and flows UI stored at 0-100%
+            slider->setValue(value*100);
+        } else {
+            slider->setValue(value); // brush size
+        }
+
+
     }
 }
 
@@ -812,8 +821,10 @@ void KisPaintopBox::slotCreatePresetFromScratch(QString paintop)
     //manually set the engine to use a new preset.
     KoID id(paintop, KisPaintOpRegistry::instance()->get(paintop)->name());
     KisPaintOpPresetSP preset = defaultPreset(id);
+
+    slotSetPaintop(paintop);  // change the paintop settings area and update the UI
+
     if (!preset) {
-        slotSetPaintop(paintop);  // change the paintop settings area and update the UI
         m_presetsPopup->setCreatingBrushFromScratch(true); // disable UI elements while creating from scratch
         preset = m_resourceProvider->currentPreset();
     } else {
@@ -1010,8 +1021,10 @@ void KisPaintopBox::sliderChanged(int n)
 
     KisSignalsBlocker blocker(m_optionWidget);
 
-    qreal opacity = m_sliderChooser[n]->getWidget<KisDoubleSliderSpinBox>("opacity")->value();
-    qreal flow    = m_sliderChooser[n]->getWidget<KisDoubleSliderSpinBox>("flow")->value();
+    // flow and opacity are shown as 0-100% on the UI, but their data is actually 0-1. Convert those two values
+    // back for further work
+    qreal opacity = m_sliderChooser[n]->getWidget<KisDoubleSliderSpinBox>("opacity")->value()/100;
+    qreal flow    = m_sliderChooser[n]->getWidget<KisDoubleSliderSpinBox>("flow")->value()/100;
     qreal size    = m_sliderChooser[n]->getWidget<KisDoubleSliderSpinBox>("size")->value();
 
 
