@@ -36,28 +36,33 @@ public:
 
     KisColorSelector(KisColorSelectorConfiguration conf, QWidget* parent = 0);
     KisColorSelector(QWidget* parent=0);
-    KisColorSelectorBase* createPopup() const;
+    KisColorSelectorBase* createPopup() const override;
 
     void setConfiguration(KisColorSelectorConfiguration conf);
     KisColorSelectorConfiguration configuration() const;
-    void setColor(const KoColor &color);
+    void setColor(const KoColor &color) override;
+
+    /// update icons when a theme update happens
+    void updateIcons();
+
+    void hasAtLeastOneDocument(bool value);
 
 public Q_SLOTS:
-    void reset();
-    void updateSettings();
+    void reset() override;
+    void updateSettings() override;
+
 
 Q_SIGNALS:
     void settingsButtonClicked();
 
 protected:
-    void paintEvent(QPaintEvent*);
-    void resizeEvent(QResizeEvent*);
-    void mousePressEvent(QMouseEvent*);
-    void mouseMoveEvent(QMouseEvent*);
-    void mouseReleaseEvent(QMouseEvent*);
+    void paintEvent(QPaintEvent*) override;
+    void resizeEvent(QResizeEvent*) override;
+    void mousePressEvent(QMouseEvent*) override;
+    void mouseMoveEvent(QMouseEvent*) override;
+    void mouseReleaseEvent(QMouseEvent*) override;
     bool displaySettingsButton();
 
-
 private:
     void mouseEvent(QMouseEvent* e);
     void init();
@@ -82,6 +87,12 @@ private:
     Acs::ColorRole m_lastColorRole;
 
 
+    /// if Krita starts with a reference to this componenet that is attached to a canvas, it will call setCanvas()
+    /// that check will be what ultimately decides whether this component will look enabled or disabled
+    /// This color selector is sometimes not attached to the canvas, so we shouldn't disable it in that situation
+    /// One instane of that is when you select the color wheel type from the settings.
+    bool m_hasAtLeastOneDocumentOpen = true;
+
 public:
     void setDisplayBlip(bool disp) {m_blipDisplay = disp;}
     bool displayBlip() const {return m_blipDisplay;}
