@@ -31,6 +31,7 @@
 #include <kis_fixed_paint_device.h>
 #include <kis_image.h>
 #include <kis_lod_transform.h>
+#include <kis_paintop_plugin_utils.h>
 
 
 KisTangentNormalPaintOp::KisTangentNormalPaintOp(const KisPaintOpSettingsSP settings, KisPainter* painter, KisNodeSP node, KisImageSP image):
@@ -42,10 +43,12 @@ KisTangentNormalPaintOp::KisTangentNormalPaintOp(const KisPaintOpSettingsSP sett
     Q_UNUSED(image);
     //Init, read settings, etc//
     m_tangentTiltOption.readOptionSetting(settings);
+    m_airbrushOption.readOptionSetting(settings);
     m_sizeOption.readOptionSetting(settings);
     m_opacityOption.readOptionSetting(settings);
     m_flowOption.readOptionSetting(settings);
     m_spacingOption.readOptionSetting(settings);
+    m_rateOption.readOptionSetting(settings);
     m_softnessOption.readOptionSetting(settings);
     m_sharpnessOption.readOptionSetting(settings);
     m_rotationOption.readOptionSetting(settings);
@@ -55,6 +58,7 @@ KisTangentNormalPaintOp::KisTangentNormalPaintOp(const KisPaintOpSettingsSP sett
     m_opacityOption.resetAllSensors();
     m_flowOption.resetAllSensors();
     m_spacingOption.resetAllSensors();
+    m_rateOption.resetAllSensors();
     m_softnessOption.resetAllSensors();
     m_sharpnessOption.resetAllSensors();
     m_rotationOption.resetAllSensors();
@@ -80,9 +84,9 @@ KisSpacingInformation KisTangentNormalPaintOp::paintAt(const KisPaintInformation
     QString currentSpace = currentColor.colorSpace()->colorModelId().id();
     const KoColorSpace* rgbColorSpace = KoColorSpaceRegistry::instance()->rgb8();
     if (currentSpace != "RGBA") {
-    rgbColorSpace = KoColorSpaceRegistry::instance()->rgb8();
+        rgbColorSpace = KoColorSpaceRegistry::instance()->rgb8();
     } else {
-    rgbColorSpace = currentColor.colorSpace();
+        rgbColorSpace = currentColor.colorSpace();
     }
     QVector <float> channelValues(4);
     qreal r, g, b;
@@ -130,15 +134,15 @@ KisSpacingInformation KisTangentNormalPaintOp::paintAt(const KisPaintInformation
 
 
     QPointF cursorPos =
-        m_scatterOption.apply(info,
-                              brush->maskWidth(shape, 0, 0, info),
-                              brush->maskHeight(shape, 0, 0, info));
+            m_scatterOption.apply(info,
+                                  brush->maskWidth(shape, 0, 0, info),
+                                  brush->maskHeight(shape, 0, 0, info));
 
     m_maskDab =
-        m_dabCache->fetchDab(rgbColorSpace, color, cursorPos,
-                             shape,
-                             info, m_softnessOption.apply(info),
-                             &m_dstDabRect);
+            m_dabCache->fetchDab(rgbColorSpace, color, cursorPos,
+                                 shape,
+                                 info, m_softnessOption.apply(info),
+                                 &m_dstDabRect);
 
     if (m_dstDabRect.isEmpty()) return KisSpacingInformation(1.0);
 
@@ -160,12 +164,29 @@ KisSpacingInformation KisTangentNormalPaintOp::paintAt(const KisPaintInformation
     painter()->bltFixed(m_dstDabRect.topLeft(), m_maskDab, m_maskDab->bounds());
     painter()->renderMirrorMaskSafe(m_dstDabRect, m_maskDab, !m_dabCache->needSeparateOriginal());
 
-    // restore orginal opacity and composite mode values
+    // restore original opacity and composite mode values
     painter()->setOpacity(oldOpacity);
     painter()->setCompositeOp(oldCompositeOpId);
 
-    return effectiveSpacing(scale, rotation,
-                            m_spacingOption, info);
+    return computeSpacing(info, scale, rotation);
+}
+
+KisSpacingInformation KisTangentNormalPaintOp::updateSpacingImpl(const KisPaintInformation &info) const
+{
+    qreal scale = m_sizeOption.apply(info) * KisLodTransform::lodToScale(painter()->device());
+    qreal rotation = m_rotationOption.apply(info);
+    return computeSpacing(info, scale, rotation);
+}
+
+KisTimingInformation KisTangentNormalPaintOp::updateTimingImpl(const KisPaintInformation &info) const
+{
+    return KisPaintOpPluginUtils::effectiveTiming(&m_airbrushOption, &m_rateOption, info);
+}
+
+KisSpacingInformation KisTangentNormalPaintOp::computeSpacing(const KisPaintInformation &info,
+                                                              qreal scale, qreal rotation) const
+{
+    return effectiveSpacing(scale, rotation, &m_airbrushOption, &m_spacingOption, info);
 }
 
 void KisTangentNormalPaintOp::paintLine(const KisPaintInformation& pi1, const KisPaintInformation& pi2, KisDistanceInformation *currentDistance)
@@ -180,51 +201,51 @@ void KisTangentNormalPaintOp::paintLine(const KisPaintInformation& pi1, const Ki
         }
 
         KisPainter p(m_lineCacheDevice);
-    KoColor currentColor = painter()->paintColor();
-    QString currentSpace = currentColor.colorSpace()->colorModelId().id();
-    const KoColorSpace* rgbColorSpace = KoColorSpaceRegistry::instance()->rgb8();
-    if (currentSpace != "RGBA") {
-        rgbColorSpace = KoColorSpaceRegistry::instance()->rgb8();
-    } else {
-        rgbColorSpace = currentColor.colorSpace();
-    }
-    QVector <float> channelValues(4);
-    qreal r, g, b;
+        KoColor currentColor = painter()->paintColor();
+        QString currentSpace = currentColor.colorSpace()->colorModelId().id();
+        const KoColorSpace* rgbColorSpace = KoColorSpaceRegistry::instance()->rgb8();
+        if (currentSpace != "RGBA") {
+            rgbColorSpace = KoColorSpaceRegistry::instance()->rgb8();
+        } else {
+            rgbColorSpace = currentColor.colorSpace();
+        }
+        QVector <float> channelValues(4);
+        qreal r, g, b;
 
-    if (currentColor.colorSpace()->colorDepthId().id()=="F16" || currentColor.colorSpace()->colorDepthId().id()=="F32"){
-        channelValues[0] = 0.5;//red
-        channelValues[1] = 0.5;//green
-        channelValues[2] = 1.0;//blue
-        channelValues[3] = 1.0;//alpha, leave alone.
+        if (currentColor.colorSpace()->colorDepthId().id()=="F16" || currentColor.colorSpace()->colorDepthId().id()=="F32"){
+            channelValues[0] = 0.5;//red
+            channelValues[1] = 0.5;//green
+            channelValues[2] = 1.0;//blue
+            channelValues[3] = 1.0;//alpha, leave alone.
 
 
-        m_tangentTiltOption.apply(pi2, &r, &g, &b);
+            m_tangentTiltOption.apply(pi2, &r, &g, &b);
 
-        channelValues[0] = r;//red
-        channelValues[1] = g;//green
-        channelValues[2] = b;//blue
-    } else {
-        channelValues[0] = 1.0;//blue
-        channelValues[1] = 0.5;//green
-        channelValues[2] = 0.5;//red
-        channelValues[3] = 1.0;//alpha, leave alone.
+            channelValues[0] = r;//red
+            channelValues[1] = g;//green
+            channelValues[2] = b;//blue
+        } else {
+            channelValues[0] = 1.0;//blue
+            channelValues[1] = 0.5;//green
+            channelValues[2] = 0.5;//red
+            channelValues[3] = 1.0;//alpha, leave alone.
 
-        m_tangentTiltOption.apply(pi2, &r, &g, &b);
+            m_tangentTiltOption.apply(pi2, &r, &g, &b);
 
-        channelValues[0] = b;//blue
-        channelValues[1] = g;//green
-        channelValues[2] = r;//red
-    }
+            channelValues[0] = b;//blue
+            channelValues[1] = g;//green
+            channelValues[2] = r;//red
+        }
 
-    quint8 data[4];
-    rgbColorSpace->fromNormalisedChannelsValue(data, channelValues);
-    KoColor color(data, rgbColorSpace);
+        quint8 data[4];
+        rgbColorSpace->fromNormalisedChannelsValue(data, channelValues);
+        KoColor color(data, rgbColorSpace);
         p.setPaintColor(color);
         p.drawDDALine(pi1.pos(), pi2.pos());
 
         QRect rc = m_lineCacheDevice->extent();
         painter()->bitBlt(rc.x(), rc.y(), m_lineCacheDevice, rc.x(), rc.y(), rc.width(), rc.height());
-    painter()->renderMirrorMask(rc, m_lineCacheDevice);
+        painter()->renderMirrorMask(rc, m_lineCacheDevice);
     }
     else {
         KisPaintOp::paintLine(pi1, pi2, currentDistance);
