@@ -29,7 +29,6 @@
 #include <QApplication>
 #include <QCheckBox>
 #include <QVBoxLayout>
-#include <QHBoxLayout>
 
 #include <kis_debug.h>
 #include <klocalizedstring.h>
@@ -53,6 +52,7 @@
 #include "kis_pixel_selection.h"
 #include "tiles3/kis_hline_iterator.h"
 
+
 KisToolSelectContiguous::KisToolSelectContiguous(KoCanvasBase *canvas)
     : KisToolSelectBase<KisTool>(canvas,
                                  KisCursor::load("tool_contiguous_selection_cursor.png", 6, 6),
@@ -79,7 +79,6 @@ void KisToolSelectContiguous::activate(ToolActivation toolActivation, const QSet
 
 void KisToolSelectContiguous::beginPrimaryAction(KoPointerEvent *event)
 {
-
     KisToolSelectBase::beginPrimaryAction(event);
     KisPaintDeviceSP dev;
 
@@ -93,19 +92,20 @@ void KisToolSelectContiguous::beginPrimaryAction(KoPointerEvent *event)
 
     QApplication::setOverrideCursor(KisCursor::waitCursor());
 
-    QPoint pos = convertToIntPixelCoord(event);
+
+    QPoint pos = convertToImagePixelCoordFloored(event);
     QRect rc = currentImage()->bounds();
     KisFillPainter fillpainter(dev);
     fillpainter.setHeight(rc.height());
     fillpainter.setWidth(rc.width());
     fillpainter.setFillThreshold(m_fuzziness);
+    fillpainter.setFeather(m_feather);
+    fillpainter.setSizemod(m_sizemod);
 
     KisImageWSP image = currentImage();
     KisPaintDeviceSP sourceDevice = m_limitToCurrentLayer ? dev : image->projection();
 
     image->lock();
-    fillpainter.setFeather(m_feather);
-    fillpainter.setSizemod(m_sizemod);
     KisSelectionSP selection = fillpainter.createFloodSelection(pos.x(), pos.y(), sourceDevice);
     image->unlock();
 
@@ -136,6 +136,7 @@ void KisToolSelectContiguous::beginPrimaryAction(KoPointerEvent *event)
     KisSelectionToolHelper helper(kisCanvas, kundo2_i18n("Select Contiguous Area"));
     helper.selectPixelSelection(selection->pixelSelection(), selectionAction());
     QApplication::restoreOverrideCursor();
+
 }
 
 void KisToolSelectContiguous::paint(QPainter &painter, const KoViewConverter &converter)
@@ -172,12 +173,12 @@ QWidget* KisToolSelectContiguous::createOptionWidget()
     QVBoxLayout * l = dynamic_cast<QVBoxLayout*>(selectionWidget->layout());
     Q_ASSERT(l);
     if (l) {
-        QHBoxLayout * hbox = new QHBoxLayout();
-        Q_CHECK_PTR(hbox);
-        l->insertLayout(1, hbox);
+
+        QGridLayout * gridLayout = new QGridLayout();
+        l->insertLayout(1, gridLayout);
 
         QLabel * lbl = new QLabel(i18n("Fuzziness: "), selectionWidget);
-        hbox->addWidget(lbl);
+        gridLayout->addWidget(lbl, 0, 0, 1, 1);
 
         KisSliderSpinBox *input = new KisSliderSpinBox(selectionWidget);
         Q_CHECK_PTR(input);
@@ -185,34 +186,27 @@ QWidget* KisToolSelectContiguous::createOptionWidget()
         input->setRange(1, 100);
         input->setSingleStep(1);
         input->setExponentRatio(2);
-        hbox->addWidget(input);
-
-        hbox = new QHBoxLayout();
-        Q_CHECK_PTR(hbox);
-        l->insertLayout(2, hbox);
+        gridLayout->addWidget(input, 0, 1, 1, 1);
 
         lbl = new QLabel(i18n("Grow/shrink selection: "), selectionWidget);
-        hbox->addWidget(lbl);
+        gridLayout->addWidget(lbl, 1, 0, 1, 1);
 
         KisSliderSpinBox *sizemod = new KisSliderSpinBox(selectionWidget);
         Q_CHECK_PTR(sizemod);
         sizemod->setObjectName("sizemod"); //grow/shrink selection
         sizemod->setRange(-40, 40);
         sizemod->setSingleStep(1);
-        hbox->addWidget(sizemod);
+        gridLayout->addWidget(sizemod, 1, 1, 1, 1);
 
-        hbox = new QHBoxLayout();
-        Q_CHECK_PTR(hbox);
-        l->insertLayout(3, hbox);
-
-        hbox->addWidget(new QLabel(i18n("Feathering radius: "), selectionWidget));
+        lbl = new QLabel(i18n("Feathering radius: "), selectionWidget);
+        gridLayout->addWidget(lbl, 2, 0, 1, 1);
 
         KisSliderSpinBox *feather = new KisSliderSpinBox(selectionWidget);
         Q_CHECK_PTR(feather);
         feather->setObjectName("feathering");
         feather->setRange(0, 40);
         feather->setSingleStep(1);
-        hbox->addWidget(feather);
+        gridLayout->addWidget(feather, 2, 1, 1, 1);
 
         connect (input  , SIGNAL(valueChanged(int)), this, SLOT(slotSetFuzziness(int) ));
         connect (sizemod, SIGNAL(valueChanged(int)), this, SLOT(slotSetSizemod(int)   ));
@@ -250,3 +244,13 @@ void KisToolSelectContiguous::setSelectionAction(int action)
 {
     changeSelectionAction(action);
 }
+
+
+QMenu* KisToolSelectContiguous::popupActionsMenu()
+{
+    KisCanvas2 * kisCanvas = dynamic_cast<KisCanvas2*>(canvas());
+    Q_ASSERT(kisCanvas);
+
+
+    return KisSelectionToolHelper::getSelectionContextMenu(kisCanvas);
+}
